@@ -83,6 +83,11 @@ enum
 };
 
 
+static GdkColor color_error = {0, 0xFFFF, 0, 0};
+static GdkColor color_context = {0, 0x7FFF, 0, 0};
+static GdkColor color_message = {0, 0, 0, 0xD000};
+
+
 static void prepare_msg_tree_view(void);
 static void prepare_status_tree_view(void);
 static void prepare_compiler_tree_view(void);
@@ -112,6 +117,37 @@ void msgwin_set_messages_dir(const gchar *messages_dir)
 }
 
 
+void load_color(const gchar *color_name, GdkColor *color)
+{
+#if GTK_CHECK_VERSION(3, 0, 0)
+	GdkRGBA rgba_color;
+	GtkWidgetPath *path = gtk_widget_path_new();
+	GtkStyleContext *ctx = gtk_style_context_new();
+
+	gtk_widget_path_append_type(path, GTK_TYPE_WINDOW);
+	gtk_widget_path_iter_set_name(path, -1, color_name);
+	gtk_style_context_set_screen(ctx, gdk_screen_get_default());
+	gtk_style_context_set_path(ctx, path);
+	gtk_style_context_get_color(ctx, gtk_style_context_get_state(ctx), &rgba_color);
+
+	color->red   = 0xffff * rgba_color.red;
+	color->green = 0xffff * rgba_color.green;
+	color->blue  = 0xffff * rgba_color.blue;
+
+	gtk_widget_path_unref(path);
+	g_object_unref(ctx);
+#else
+	gchar *path = g_strconcat("*.", color_name, NULL);
+
+	GtkSettings *settings = gtk_settings_get_default();
+	GtkStyle *style = gtk_rc_get_style_by_paths(settings, path, NULL, GTK_TYPE_WIDGET);
+	*color = style->fg[GTK_STATE_NORMAL];
+
+	g_free(path);
+#endif
+}
+
+
 void msgwin_init(void)
 {
 	msgwindow.notebook = ui_lookup_widget(main_widgets.window, "notebook_info");
@@ -130,6 +166,10 @@ void msgwin_init(void)
 
 	ui_widget_modify_font_from_string(msgwindow.scribble, interface_prefs.msgwin_font);
 	g_signal_connect(msgwindow.scribble, "populate-popup", G_CALLBACK(on_scribble_populate), NULL);
+
+	load_color("geany-compiler-error", &color_error);
+	load_color("geany-compiler-context", &color_context);
+	load_color("geany-compiler-message", &color_message);
 }
 
 
@@ -262,19 +302,13 @@ static void prepare_compiler_tree_view(void)
 	/*g_signal_connect(selection, "changed", G_CALLBACK(on_msg_tree_selection_changed), NULL);*/
 }
 
-
-static const GdkColor color_error = {0, 65535, 0, 0};
-
 static const GdkColor *get_color(gint msg_color)
 {
-	static const GdkColor dark_red = {0, 65535 / 2, 0, 0};
-	static const GdkColor blue = {0, 0, 0, 0xD000};	/* not too bright ;-) */
-
 	switch (msg_color)
 	{
 		case COLOR_RED: return &color_error;
-		case COLOR_DARK_RED: return &dark_red;
-		case COLOR_BLUE: return &blue;
+		case COLOR_DARK_RED: return &color_context;
+		case COLOR_BLUE: return &color_message;
 		default: return NULL;
 	}
 }
