@@ -14,15 +14,20 @@
  *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *      GNU General Public License for more details.
  *
- *      You should have received a copy of the GNU General Public License
- *      along with this program; if not, write to the Free Software
- *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *      You should have received a copy of the GNU General Public License along
+ *      with this program; if not, write to the Free Software Foundation, Inc.,
+ *      51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 
 #ifndef GEANY_PRINTING_H
 #define GEANY_PRINTING_H 1
 
+#include "document.h"
+
+#include <glib.h>
+
+G_BEGIN_DECLS
 
 /* General printing preferences. */
 typedef struct PrintingPrefs
@@ -43,4 +48,6 @@ void printing_page_setup_gtk(void);
 
 void printing_print_doc(GeanyDocument *doc);
 
-#endif
+G_END_DECLS
+
+#endif /* GEANY_PRINTING_H */
